@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Use this module to add the ``delroom`` subcommand to ``matrixctl``."""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser
@@ -31,6 +34,19 @@ __email__: str = "Michael@MichaelSasser.org"
 
 
 def subparser_delroom(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl delroom`` command.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by
+        ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "delroom", help="Deletes an empty room from the database"
     )
@@ -45,35 +61,41 @@ def subparser_delroom(subparsers: SubParsersAction) -> None:
 def delroom(arg: Namespace) -> int:
     """Delete an empty room from the database.
 
-    :param arg:       The ``Namespace`` object of argparse's ``arse_args()``
-    :return:          None
+    Parameters
+    ----------
+    arg : argparse.Namespace
+        The ``Namespace`` object of argparse's ``parse_args()``
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
     """
-    with TOML() as toml:
-        with API(
-            toml.get(("API", "Domain")), toml.get(("API", "Token"))
-        ) as api:
-            api.method = "POST"
-            api.url.path = "purge_room"
-            api.url.api_version = "v1"
+    toml: TOML = TOML()
+    api: API = API(toml.get("API", "Domain"), toml.get("API", "Token"))
+    api.method = "POST"
+    api.url.path = "purge_room"
+    api.url.api_version = "v1"
 
+    try:
+        api.request({"room_id": arg.RoomID}).json()
+    except InternalResponseError as e:
+        if "json" in dir(e.payload):
             try:
-                api.request({"room_id": arg.RoomID}).json()
-            except InternalResponseError as e:
-                if "json" in dir(e.payload):
-                    try:
-                        if e.payload.json()["errcode"] in (
-                            "M_NOT_FOUND",
-                            "M_UNKNOWN",
-                        ):
-                            error(f"{e.payload.json()['error']}")
+                if e.payload.json()["errcode"] in (
+                    "M_NOT_FOUND",
+                    "M_UNKNOWN",
+                ):
+                    error(f"{e.payload.json()['error']}")
 
-                            return 1
-                    except KeyError:
-                        pass  # log the fallback error
+                    return 1
+            except KeyError:
+                pass  # log the fallback error
 
-                error("Could not delete room")
+        error("Could not delete room")
 
-                return 1
+        return 1
 
     return 0
 
