@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Use this module to add the ``(re)start`` subcommand to ``matrixctl``."""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser
@@ -30,6 +33,18 @@ __email__: str = "Michael@MichaelSasser.org"
 
 
 def subparser_start(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl start`` command.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "start", help="Starts all OCI containers"
     )
@@ -37,6 +52,26 @@ def subparser_start(subparsers: SubParsersAction) -> None:
 
 
 def subparser_restart(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl restart`` command.
+
+    Notes
+    -----
+    This is a alias for ``matrixctl start``
+
+    See Also
+    --------
+    matrixctl.start.subparser_start : Subparser for ``matrixctl start``.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "restart", help="Restarts all OCI containers (alias for start)"
     )
@@ -44,11 +79,24 @@ def subparser_restart(subparsers: SubParsersAction) -> None:
 
 
 def start(_: Namespace) -> int:
+    """Start/Restart the OCI containers.
+
+    Parameters
+    ----------
+    arg : argparse.Namespace
+        The ``Namespace`` object of argparse's ``parse_args()``.
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
+    """
     debug("start")
 
-    with TOML() as toml:
-        ansible_run(toml.get(("ANSIBLE", "Playbook")), tags="start")
-        return 0
+    toml: TOML = TOML()
+    ansible_run(toml.get("ANSIBLE", "Playbook"), tags="start")
+    return 0
 
 
 # vim: set ft=python :
