@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Use this module to add the ``user`` subcommand to ``matrixctl``."""
+
 from __future__ import annotations
 
 import datetime
@@ -26,11 +29,6 @@ from logging import debug
 from logging import error
 from logging import fatal
 from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import Union
 
 from tabulate import tabulate
 
@@ -46,6 +44,18 @@ __email__: str = "Michael@MichaelSasser.org"
 
 
 def subparser_user(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl user`` command.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "user", help="Get information about a specific user"
     )
@@ -54,11 +64,33 @@ def subparser_user(subparsers: SubParsersAction) -> None:
 
 
 def make_human_readable(
-    k: str, user_dict: Dict[str, str], len_domain: int
-) -> Tuple[str, str]:
+    k: str, user_dict: dict[str, str], len_domain: int
+) -> tuple[str, str]:
+    """Make a key/value pair of a ``user`` (line) human readable, by modifying.
 
-    key: Optional[str] = None
-    value: Union[str]
+    Notes
+    -----
+    This function is used as helper by ``matrixctl.user.generate_user_tables``.
+
+    Parameters
+    ----------
+    k : str
+        The key
+    user_dict : `dict` [`str`, `Any`]
+        The line as dict, a JSON string which was converted to a Python
+        dictionary. (This is not a ``Collections.UserDict``)
+    len_domain : int
+        The length in characters of the domain.
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
+    """
+
+    key: str | None = None
+    value: str
 
     if k == "name":
         value = str(user_dict[k][1:-len_domain])
@@ -85,25 +117,36 @@ def make_human_readable(
     return key, value
 
 
+# TODO: JSON Type?
 def generate_user_tables(
-    user_dict: Dict[str, Any], len_domain: int
-) -> List[List[Tuple[str, str]]]:
+    user_dict: dict[str, Any], len_domain: int
+) -> list[list[tuple[str, str]]]:
     """Generate a main user table and threepid user tables.
 
     The function gnerates first a main user table and then for every threepid
     a additional table from a ``user_dict``.
     It renames and makes the output human readable.
 
-    This function is a recursive function
+    Notes
+    -----
+    This function is a recursive function.
+
+    Parameters
+    ----------
+    user_dict : `dict` [`str`, `Any`]
+        The line as dict, a JSON string which was converted to a Python
+        dictionary. (This is not a ``Collections.UserDict``)
+    len_domain : int
+        The length in characters of the domain.
+
+    Returns
+    -------
+    err_code : int
+        A list in the format: ``[[main], threepids_0, ... ,threepids_n]``
 
-    :param user_dict:   A JSON string which was converted to a Python
-                        dictionary.
-    :param len_domain:  The length in characters of the domain.
-    :return:            The generated lists in this format:
-                        [main], threepids_0, ... ,threepids_n]
     """
 
-    table: List[List[Tuple[str, str]]] = [[]]
+    table: list[list[tuple[str, str]]] = [[]]
 
     for k in user_dict:
         if k == "errcode":
@@ -112,7 +155,7 @@ def generate_user_tables(
 
         if k == "threepids":
             for tk in user_dict[k]:
-                ret: List[List[Tuple[str, str]]] = generate_user_tables(
+                ret: list[list[tuple[str, str]]] = generate_user_tables(
                     tk, len_domain
                 )
                 table.append(ret[0])
@@ -132,7 +175,8 @@ def user(arg: Namespace) -> int:
     The Python package ``tabulate`` renders the table as shown below, if
     everything works well.
 
-
+    Examples
+    --------
     .. code-block:: console
 
        $ matrixctl user dwight
@@ -172,41 +216,46 @@ def user(arg: Namespace) -> int:
        2020-04-14 13:58:13 - ERROR - The request was not successful.
        2020-04-14 13:58:13 - ERROR - There is no user with that username.
 
-    :param arg:       The ``Namespace`` object of argparse's ``arse_args()``
-    :param cfg:       The ``Config`` class
-    :return:          None
+    Parameters
+    ----------
+    arg : argparse.Namespace
+        The ``Namespace`` object of argparse's ``parse_args()``.
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
     """
 
-    with TOML() as toml:
-        with API(
-            toml.get(("API", "Domain")), toml.get(("API", "Token"))
-        ) as api:
-            api.url.path = f'users/@{arg.user}:{toml.get(("API","Domain"))}'
+    toml: TOML = TOML()
+    api: API = API(toml.get("API", "Domain"), toml.get("API", "Token"))
+    api.url.path = f'users/@{arg.user}:{toml.get("API","Domain")}'
 
-            try:
-                user_dict: JsonDict = api.request().json()
-            except InternalResponseError:
-                fatal("Could not receive the user information")
+    try:
+        user_dict: JsonDict = api.request().json()
+    except InternalResponseError:
+        fatal("Could not receive the user information")
 
-                return 1
+        return 1
 
-            len_domain = len(toml.get(("API", "Domain"))) + 1  # 1 for :
-            user_tables = generate_user_tables(user_dict, len_domain)
+    len_domain = len(toml.get("API", "Domain")) + 1  # 1 for :
+    user_tables = generate_user_tables(user_dict, len_domain)
 
-            debug(f"User: {user_tables=}")
+    debug(f"User: {user_tables=}")
 
-            for num, table in enumerate(user_tables):
+    for num, table in enumerate(user_tables):
 
-                if num < 1:
-                    print("User:")
-                else:
-                    print("\nThreepid:")
-                print(
-                    tabulate(
-                        table,
-                        tablefmt="psql",
-                    )
-                )
+        if num < 1:
+            print("User:")
+        else:
+            print("\nThreepid:")
+        print(
+            tabulate(
+                table,
+                tablefmt="psql",
+            )
+        )
 
     return 0
 
